Module: ActiveRecord::Userstamp::ControllerAdditions
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/active_record/userstamp/controller_additions.rb
Overview
The ControllerAdditions module, when included into a controller, adds an before_action callback (named set_stamper) and an after_action callback (named reset_stamper). These methods assume a couple of things, but can be re-implemented in your controller to better suit your application.
See the documentation for set_stamper and reset_stamper for specific implementation details.